@@ -7,31 +7,36 @@ env_default = whack.args.env_default(prefix="WHACK")
 
 
 def main(argv, operations):
+    commands = [
+        InstallCommand("install"),
+        InstallCommand("build"),
+    ]
+    
     parser = argparse.ArgumentParser()
     subparsers = parser.add_subparsers()
     
-    for command_name, command_builder in _commands.iteritems():
-        command = command_builder(operations)
-        subparser = subparsers.add_parser(command_name)
+    for command in commands:
+        subparser = subparsers.add_parser(command.name)
         subparser.set_defaults(func=command.execute)
         command.create_parser(subparser)
     
     args = parser.parse_args(argv[1:])
-    args.func(args)
+    args.func(operations, args)
+    
     
 class InstallCommand(object):
-    def __init__(self, operations):
-        self._operations = operations
+    def __init__(self, name):
+        self.name = name
     
     def create_parser(self, subparser):
         subparser.add_argument('package')
-        subparser.add_argument('install_dir', metavar="install-dir")
+        subparser.add_argument('target_dir', metavar="target-dir")
         subparser.add_argument("--no-cache", action="store_true")
         subparser.add_argument("--http-cache-url", action=env_default)
         subparser.add_argument("--http-cache-key", action=env_default)
         subparser.add_argument("--add-parameter", "-p", action="append", default=[])
     
-    def execute(self, args):
+    def execute(self, operations, args):
         params = {}
         for parameter_arg in args.add_parameter:
             if "=" in parameter_arg:
@@ -46,13 +51,16 @@ class InstallCommand(object):
             http_cache_key=args.http_cache_key
         )
         
-        self._operations.install(
+        if self.name == "install":
+            operation = operations.install
+        elif self.name == "build":
+            operation = operations.build
+        else:
+            raise Exception("Unrecognised operation")
+            
+        operation(
             package=args.package,
-            install_dir=args.install_dir,
+            install_dir=args.target_dir,
             caching=caching,
             params=params
         )
-
-_commands = {
-    "install": InstallCommand,
-}
