@@ -1,6 +1,7 @@
 import os
 import hashlib
 
+
 class Hasher(object):
     def __init__(self):
         self._hash = hashlib.sha1()
@@ -13,8 +14,25 @@ class Hasher(object):
             self.update(os.path.relpath(file_path, dir_path))
             self.update(open(file_path).read())
     
-    def hexdigest(self):
-        return self._hash.hexdigest()
+    def ascii_digest(self):
+        return integer_to_ascii(int(self._hash.hexdigest(), 16))
+
+
+def integer_to_ascii(value):
+    characters = "0123456789abcdefghijklmnopqrstuv"
+    
+    if value == 0:
+        return characters[0]
+    
+    output = []
+    remaining_value = value
+    while remaining_value > 0:
+        output.append(characters[remaining_value % len(characters)])
+        remaining_value = remaining_value // len(characters)
+    
+    
+    return "".join(reversed(output))
+
 
 def _all_files(top):
     all_files = []
@@ -25,5 +43,6 @@ def _all_files(top):
     
     return sorted(all_files)
 
+
 def _sha1(str):
     return hashlib.sha1(str).hexdigest()
